==> netdata-1.45.4.tar.gz: netdata-v1.45.4/src/go/collectors/go.d.plugin/modules/init.go <==
// SPDX-License-Identifier: GPL-3.0-or-later

package modules

import (
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/activemq"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/apache"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/bind"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/cassandra"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/chrony"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/cockroachdb"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/consul"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/coredns"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/couchbase"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/couchdb"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/dnsdist"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/dnsmasq"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/dnsmasq_dhcp"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/dnsquery"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/docker"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/docker_engine"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/dockerhub"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/elasticsearch"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/envoy"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/example"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/filecheck"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/fluentd"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/freeradius"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/geth"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/haproxy"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/hdfs"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/httpcheck"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/isc_dhcpd"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/k8s_kubelet"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/k8s_kubeproxy"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/k8s_state"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/lighttpd"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/logind"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/logstash"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/mongodb"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/mysql"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/nginx"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/nginxplus"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/nginxvts"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/ntpd"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/nvidia_smi"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/nvme"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/openvpn"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/openvpn_status_log"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/pgbouncer"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/phpdaemon"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/phpfpm"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/pihole"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/pika"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/ping"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/portcheck"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/postgres"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/powerdns"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/powerdns_recursor"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/prometheus"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/proxysql"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/pulsar"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/rabbitmq"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/redis"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/scaleio"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/snmp"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/squidlog"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/supervisord"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/systemdunits"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/tengine"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/traefik"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/unbound"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/upsd"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/vcsa"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/vernemq"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/vsphere"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/weblog"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/whoisquery"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/windows"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/wireguard"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/x509check"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/zookeeper"
)

==> netdata-1.46.3.tar.gz: netdata-v1.46.3/src/go/collectors/go.d.plugin/modules/init.go <==
// SPDX-License-Identifier: GPL-3.0-or-later

package modules

import (
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/activemq"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/adaptecraid"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/apache"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/bind"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/cassandra"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/chrony"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/clickhouse"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/cockroachdb"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/consul"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/coredns"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/couchbase"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/couchdb"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/dmcache"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/dnsdist"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/dnsmasq"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/dnsmasq_dhcp"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/dnsquery"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/docker"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/docker_engine"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/dockerhub"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/elasticsearch"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/envoy"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/example"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/fail2ban"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/filecheck"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/fluentd"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/freeradius"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/geth"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/haproxy"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/hddtemp"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/hdfs"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/hpssa"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/httpcheck"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/intelgpu"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/isc_dhcpd"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/k8s_kubelet"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/k8s_kubeproxy"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/k8s_state"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/lighttpd"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/litespeed"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/logind"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/logstash"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/lvm"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/megacli"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/mongodb"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/mysql"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/nginx"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/nginxplus"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/nginxvts"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/ntpd"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/nvidia_smi"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/nvme"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/openvpn"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/openvpn_status_log"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/pgbouncer"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/phpdaemon"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/phpfpm"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/pihole"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/pika"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/ping"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/portcheck"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/postgres"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/powerdns"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/powerdns_recursor"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/prometheus"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/proxysql"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/pulsar"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/rabbitmq"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/redis"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/rspamd"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/scaleio"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/sensors"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/smartctl"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/snmp"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/squidlog"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/storcli"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/supervisord"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/systemdunits"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/tengine"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/traefik"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/unbound"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/upsd"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/vcsa"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/vernemq"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/vsphere"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/weblog"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/whoisquery"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/windows"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/wireguard"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/x509check"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/zfspool"
	_ "github.com/netdata/netdata/go/go.d.plugin/modules/zookeeper"
)
